@@ -6,6 +6,7 @@ import logging
 
 from dvc.cli import parse_args
 from dvc.lock import LockError
+from dvc.logger import FOOTER
 from dvc.config import ConfigError
 from dvc.analytics import Analytics
 from dvc.exceptions import NotDvcRepoError, DvcParserError
@@ -75,6 +76,9 @@ def main(argv=None):
         # so won't be reused by any other subsequent run anyway.
         clean_repos()
 
+    if ret != 0:
+        logger.info(FOOTER)
+
     Analytics().send_cmd(cmd, args, ret)
 
     return ret
